Skip to contents

A method for imputation of missing values in single cell RNA-sequencing data based on the average expression value of nearest neighbor cells.

Usage

imputation_KNN(obj, assay = "RNA", LogNormalized = TRUE)

Arguments

obj

A seurat object.

assay

The assay for imputation. The default is 'RNA'.

LogNormalized

Whether the data is LogNormalized.

Value

A seurat object after imputaion.