Skip to contents

scPAS.prediction: A function that uses the scPAS model to make predictions on independent data

Usage

scPAS.prediction(
  model,
  test.data,
  assay = "RNA",
  FDR.threshold = 0.05,
  do_imputation = FALSE,
  imputation_method = "KNN",
  independent = TRUE,
  permutation_times = 2000,
  n_cores = 1
)

Arguments

model

Seurat object. A Seurat object containing the scPAS model (from running scPAS()).

test.data

Matrix or Seurat object. Single-cell RNA-seq expression matrix of related disease. Each row represents a gene and each column represents a sample. A Seurat object that contains the preprocessed data and constructed network is preferred.

assay

Name of Assay to get.

FDR.threshold

Numeric. FDR value threshold for identifying phenotype-associated cells. The default is 0.05.

do_imputation

Logical. Whether to perform imputation on the test data (default: FALSE).

imputation_method

Character. Imputation method: "KNN" or "ALRA".

independent

Logical. Whether to compute background distribution independently for each cell.

permutation_times

Integer. Number of permutations for significance testing (default: 2000).

n_cores

Integer. Number of CPU cores for parallel processing (default: 1).

Value

A seurat object or data frame containing the forecast results.