A method for imputation of missing values in single cell RNA-sequencing data based on the average expression value of nearest neighbor cells.
Source:R/scPAS.R
imputation_KNN.RdA method for imputation of missing values in single cell RNA-sequencing data based on the average expression value of nearest neighbor cells.